/*************************************************************************
 * AIZO CONFIDENTIAL
 * __________________
 *
 *  [2011] - [2013] AIZO AG
 *  All Rights Reserved.
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of Aizo AG. The intellectual and technical concepts
 * contained herein are proprietary to Aizo AG and may be covered
 * by European and Foreign Patents, patents in process, and are
 * protected by trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from AIZO AG.
 * Authors: Sebastian Scholz <digitalstrom@sunshine-studios.org>
 *          Andreas Brauchli <andreas.brauchli@aizo.com>
 */

Ext.define('DSS.addon.Metering.MeteringModel', {
    extend: 'Ext.data.Model',
    fields: [{
        name: 'date',
        type: 'date',
        dateFormat: 'timestamp',
        mapping: 0,
        convert: function(v, m) {
            var res = Ext.getCmp('metering-main-panel').centerPanel.resolution;
            if (Ext.isDate(v)) {
                return new Date(v.getTime() - (res * 1000));
            }
            return new Date((v - res) * 1000);
        }
    }, {
        name: 'value',
        type: 'float',
        defaultValue: 0.0,
        mapping: 1
    }]
});

Ext.define('DSS.addon.Metering.MeteringStore', {
    extend: 'Ext.data.Store',

    model: 'DSS.addon.Metering.MeteringModel',
    proxy: {
        type: 'ajax',
        pageParam: undefined,
        limitParam: undefined,
        startParam: undefined,
        reader: {
            type: 'array',
            root: 'result.values',
            successProperty: 'ok'
        }
    }
});

Ext.define('DSS.addon.Metering.stores.CircuitModel', {
    extend: 'Ext.data.Model',
    fields: ['name', 'dsid', 'text'],
    proxy: {
        type: 'ajax',
        actionMethods: {
            read: 'GET'
        },
        url: '/json/apartment/getCircuits',
        pageParam: undefined,
        limitParam: undefined,
        startParam: undefined,
        reader: {
            type: 'json',
            root: 'result.circuits',
            successProperty: 'ok'
        }
    },

    constructor: function(data, id, raw) {
        var o = data || raw;
        if (o) {
            o.text = o.name || o.dsid.slice(16);
        }

        this.callParent(arguments);
    }
});

Ext.define('DSS.addon.Metering.stores.ResolutionModel', {
    extend: 'Ext.data.Model',
    fields: ['resolution', 'name', 'type'],
    proxy: {
        type: 'ajax',
        actionMethods: {
            read: 'GET'
        },
        url: '/json/metering/getResolutions',
        pageParam: undefined,
        limitParam: undefined,
        startParam: undefined,
        reader: {
            type: 'json',
            root: 'result.resolutions',
            successProperty: 'ok'
        }
    },
    constructor: function(data) {
        data.name = DSS.addon.Metering.time[data.resolution] || data.resolution;
        this.callParent(arguments);
    }
});

Ext.define('DSS.addon.Metering.stores.ResolutionStore', {
    extend: 'Ext.data.Store',
    model: 'DSS.addon.Metering.stores.ResolutionModel',
    // preconfigured values, use .load() for native values (mainly the same)
    data: [
        { resolution: 1, type: 'consumption' },
        { resolution: 60, type: null },
        { resolution: 900, type: 'energyDelta' },
        { resolution: 86400,type: 'energyDelta' },
        { resolution: 604800,type: 'energyDelta' }
        // Don't show monthly data as it's not calendar-month based
        // { resolution: 2592000,type: 'energyDelta' }
    ]
});
